Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // ErrQueueNotStarted error used whenever an action is required on a dynamic queue // that has not been started yet. ErrQueueNotStarted = fmt.Errorf("Start must be called before") // ErrJobFailed error is used to wrap errors provided by failing jobs. ErrJobFailed = fmt.Errorf("job failed") )
Functions ¶
This section is empty.
Types ¶
type DynamicScheduler ¶ added in v0.4.0
type Queue ¶ added in v0.4.0
type Queue[Result JobResult] interface { GetResults() []Result GetErrors(flush bool) []error FlushErrors() DynamicScheduler[Result] StaticScheduler[Result] }
Click to show internal directories.
Click to hide internal directories.